@@ -78,7 +78,7 @@ SearchStore::List SearchStore::searchStores()
 
     const QStringList paths = QCoreApplication::libraryPaths();
     for (const QString &libraryPath : paths) {
-        const QString path(libraryPath + QStringLiteral("/pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/akonadi"));
+        const QString path(libraryPath + QStringLiteral("/pim6/akonadi"));
         QDir dir(path);
 
         if (!dir.exists()) {
@@ -125,3 +125,5 @@ SearchStore::List SearchStore::searchStores()
     }
     return stores;
 }
+
+#include "moc_searchstore.cpp"
